#include <stdio.h>
#include <stdlib.h>
#include <vlc/vlc.h>
#include <unistd.h>

libvlc_instance_t *vlc;

int main(int argc, char **argv)
{
	static const char *vlc_args[] = {"test", "-I", "dummy", "--ignore-config", 0};
	libvlc_exception_t err;
	libvlc_media_t *media;
	libvlc_media_player_t *mplay;

	if(argc < 2) {
		fprintf(stderr, "please specify a video file\n");
		return 1;
	}

	printf("using libvlc version: %s\n", libvlc_get_version());

	libvlc_exception_init(&err);

	vlc = libvlc_new(4, vlc_args, &err);
	if(libvlc_exception_raised(&err)) {
		fprintf(stderr, "failed to initialize libvlc: %s\n", libvlc_exception_get_message(&err));
		return 1;
	}

	media = libvlc_media_new(vlc, argv[1], &err);
	if(libvlc_exception_raised(&err)) {
		fprintf(stderr, "failed to load %s: %s\n", argv[1], libvlc_exception_get_message(&err));
		libvlc_release(vlc);
		return 1;
	}

	/* that's a bit too high level for our purposes */
	mplay = libvlc_media_player_new_from_media(media, &err);
	if(libvlc_exception_raised(&err)) {
		fprintf(stderr, "failed to start player: %s\n", libvlc_exception_get_message(&err));
		libvlc_release(vlc);
		return 1;
	}

	libvlc_media_player_play(mplay, &err);
	if(libvlc_exception_raised(&err)) {
		fprintf(stderr, "failed to start playback: %s\n", libvlc_exception_get_message(&err));
		libvlc_release(vlc);
		return 1;
	}

	sleep(10);

	libvlc_media_player_stop(mplay, &err);
	libvlc_media_player_release(mplay);

	libvlc_release(vlc);
	return 0;
}
